@@ -41,7 +41,7 @@ module REXML
 		# _Examples_
 		#  c = CData.new( " Some text " )
 		#  c.write( $stdout )     #->  <![CDATA[ Some text ]]>
-		def write( output, indent=-1 )
+		def write( output, indent=-1, transitive=false )
 			indent( output, indent )
 			output << START
 			output << @string
@@ -52,5 +52,9 @@ module REXML
 		def CData.parse_stream(source, listener)
 			listener.cdata(source.match( PATTERN, true )[1])
 		end
+
+		def CData.pull( source )
+			source.match( PATTERN, true )[1]
+		end
 	end
 end
