@@ -148,12 +148,12 @@ module REXML
 			string[ string.index(test)+1..-1 ]
 		end
 
-		# Take equal portions of Mike Stok and Sean Russell; mix vigorously, and
-		# pour into a tall, chilled glass.  Serves 10,000.
-		def Functions::substring( string, start, length=0 )
+		# Take equal portions of Mike Stok and Sean Russell; mix 
+		# vigorously, and pour into a tall, chilled glass.  Serves 10,000.
+		def Functions::substring( string, start, length=nil )
 			ruby_string = string(string)
 			ruby_length = if length.nil? 
-											string.length
+											ruby_string.length.to_f
 										else
 											number(length)
 										end
